@@ -113,7 +113,7 @@ class CaseHandler(object):
         """
         hgnc_id = self.hgnc_id(hgnc_symbol=query_term)
         if hgnc_id is None:
-            LOG.debug(f"No gene with the HGNC symbol {hgnc_id} found.")
+            LOG.debug(f"No gene with the HGNC symbol {query_term} found.")
             query["_id"] = {"$in": []}  # No result should be returned by query
 
         unwind = "$causatives"
@@ -692,7 +692,6 @@ class CaseHandler(object):
             - gene_fusion_report: path to the gene fusions report
             - gene_fusion_report_research: path to the research gene fusions report
             - genome_build: If there is a new genome build
-            - genome_version: - || -
             - has_strvariants: If there are new strvariants
             - has_svvariants: If there are new svvariants
             - individuals: There could be new individuals
@@ -759,7 +758,6 @@ class CaseHandler(object):
                     "gene_fusion_report": case_obj.get("gene_fusion_report"),
                     "gene_fusion_report_research": case_obj.get("gene_fusion_report_research"),
                     "genome_build": case_obj.get("genome_build", "37"),
-                    "genome_version": case_obj.get("genome_version"),
                     "has_strvariants": case_obj.get("has_strvariants"),
                     "has_svvariants": case_obj.get("has_svvariants"),
                     "individuals": case_obj["individuals"],
