@@ -84,11 +84,21 @@ INDEXES = {
     "hpo_term": [
         IndexModel([("description", ASCENDING)], name="description"),
         IndexModel([("description", TEXT)], default_language="english", name="description_text"),
-        IndexModel([("hpo_number", ASCENDING)], name="number"),
+        IndexModel([("hpo_number", ASCENDING)], name="number", background=True),
     ],
     "event": [
         IndexModel([("category", ASCENDING), ("verb", ASCENDING)], name="category_verb"),
         IndexModel([("variant_id", ASCENDING)], name="variant_id"),
+        IndexModel(
+            [
+                ("institute", ASCENDING),
+                ("case", ASCENDING),
+                ("category", ASCENDING),
+                ("verb", ASCENDING),
+            ],
+            name="case_verb",
+        ),
+        IndexModel([("user_id", ASCENDING)], name="user_events"),
     ],
     "transcript": [
         IndexModel(
@@ -104,6 +114,5 @@ INDEXES = {
             background=True,
         )
     ],
-    "hpo_term": [IndexModel([("hpo_number", ASCENDING)], name="number", background=True)],
     "case": [IndexModel([("synopsis", TEXT)], default_language="english", name="synopsis_text")],
 }
