@@ -5,7 +5,7 @@
 Ref: http://stackoverflow.com/questions/4655610#comment5129510_4656431
 """
 
-from scout.constants import CONSERVATION, GENETIC_MODELS, VARIANT_CALL, CLINSIG_MAP
+from scout.constants import CLINSIG_MAP, CONSERVATION, GENETIC_MODELS, VARIANT_CALL
 
 variant = dict(
     # document_id is a md5 string created by institute_genelist_caseid_variantid:
@@ -56,6 +56,8 @@ variant = dict(
     str_pathologic_min=int,
     str_swegen_mean=float,
     str_swegen_std=float,
+    # mitochondrial variants
+    mitomap_associated_diseases=str,
     # Gene ids:
     hgnc_ids=list,  # list of hgnc ids (int)
     hgnc_symbols=list,  # list of hgnc symbols (str)
