@@ -25,7 +25,7 @@ from flask_weasyprint import HTML, render_pdf
 from werkzeug.datastructures import Headers
 
 from scout.constants import CUSTOM_CASE_REPORTS, SAMPLE_SOURCE
-from scout.server.extensions import gens, mail, store
+from scout.server.extensions import gens, mail, matchmaker, store
 from scout.server.utils import institute_and_case, templated, user_institutes, zip_dir_to_obj
 
 from . import controllers
@@ -67,7 +67,7 @@ def case(institute_id, case_name):
     return dict(
         institute=institute_obj,
         case=case_obj,
-        mme_nodes=current_app.mme_nodes,
+        mme_nodes=matchmaker.connected_nodes,
         tissue_types=SAMPLE_SOURCE,
         gens_info=gens.connection_settings(case_obj.get("genome_build")),
         **data,
@@ -103,31 +103,8 @@ def beacon_remove(case_id):
 @templated("cases/matchmaker.html")
 def matchmaker_matches(institute_id, case_name):
     """Show all MatchMaker matches for a given case"""
-    # check that only authorized users can access MME patients matches
-    panel = 1
-    if request.method == "POST":
-        panel = request.form.get("pane_id")
-    user_obj = store.user(current_user.email)
-    if "mme_submitter" not in user_obj["roles"]:
-        flash("unauthorized request", "warning")
-        return redirect(request.referrer)
-    # Required params for getting matches from MME server:
-    mme_base_url = current_app.config.get("MME_URL")
-    mme_token = current_app.config.get("MME_TOKEN")
-    if not mme_base_url or not mme_token:
-        flash(
-            "An error occurred reading matchmaker connection parameters. Please check config file!",
-            "danger",
-        )
-        return redirect(request.referrer)
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    data = controllers.mme_matches(case_obj, institute_obj, mme_base_url, mme_token)
-    data["panel"] = panel
-    if data and data.get("server_errors"):
-        flash("MatchMaker server returned error:{}".format(data["server_errors"]), "danger")
-        return redirect(request.referrer)
-    if not data:
-        data = {"institute": institute_obj, "case": case_obj, "panel": panel}
+
+    data = controllers.matchmaker_matches(request, institute_id, case_name)
     return data
 
 
@@ -136,190 +113,23 @@ def matchmaker_match(institute_id, case_name, target):
     """Starts an internal match or a match against one or all MME external nodes"""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
 
-    # check that only authorized users can run matches
-    user_obj = store.user(current_user.email)
-    if "mme_submitter" not in user_obj["roles"]:
-        flash("unauthorized request", "warning")
-        return redirect(request.referrer)
-
-    # Required params for sending an add request to MME:
-    mme_base_url = current_app.config.get("MME_URL")
-    mme_accepts = current_app.config.get("MME_ACCEPTS")
-    mme_token = current_app.config.get("MME_TOKEN")
-    nodes = current_app.mme_nodes
-
-    if not mme_base_url or not mme_token or not mme_accepts:
-        flash(
-            "An error occurred reading matchmaker connection parameters. Please check config file!",
-            "danger",
-        )
-        return redirect(request.referrer)
-
-    match_results = controllers.mme_match(
-        case_obj, target, mme_base_url, mme_token, nodes, mme_accepts
-    )
-    ok_responses = 0
-    for match_results in match_results:
-        if match_results["status_code"] == 200:
-            ok_responses += 1
-    if ok_responses:
-        flash("Match request sent. Look for eventual matches in 'Matches' page.", "info")
-    else:
-        flash("An error occurred while sending match request.", "danger")
-
+    match_results = controllers.matchmaker_match(request, target, institute_id, case_name)
     return redirect(request.referrer)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/mme_add", methods=["POST"])
 def matchmaker_add(institute_id, case_name):
     """Add or update a case in MatchMaker"""
-
-    # check that only authorized users can add patients to MME
-    user_obj = store.user(current_user.email)
-    if "mme_submitter" not in user_obj["roles"]:
-        flash("unauthorized request", "warning")
-        return redirect(request.referrer)
-
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    causatives = False
-    features = False
-    if case_obj.get("suspects") and len(case_obj.get("suspects")) > 3:
-        flash(
-            "At the moment it is not possible to save to MatchMaker more than 3 pinned variants",
-            "warning",
-        )
-        return redirect(request.referrer)
-    if case_obj.get("suspects"):
-        causatives = True
-    if case_obj.get("phenotype_terms"):
-        features = True
-
-    mme_save_options = ["sex", "features", "disorders"]
-    for index, item in enumerate(mme_save_options):
-        if item in request.form:
-            LOG.info("item {} is in request form".format(item))
-            mme_save_options[index] = True
-        else:
-            mme_save_options[index] = False
-    genomic_features = request.form.get("genomicfeatures")
-    genes_only = True  # upload to matchmaker only gene names
-    if genomic_features == "variants":
-        genes_only = False  # upload to matchmaker both variants and gene names
-
-    # If there are no genomic features nor HPO terms to share for this case, abort
-    if (not case_obj.get("suspects") and not mme_save_options[1]) or (
-        causatives is False and features is False
-    ):
-        flash(
-            "In order to upload a case to MatchMaker you need to pin a variant or at least assign a phenotype (HPO term)",
-            "danger",
-        )
-        return redirect(request.referrer)
-
-    user_obj = store.user(current_user.email)
-
-    # Required params for sending an add request to MME:
-    mme_base_url = current_app.config.get("MME_URL")
-    mme_accepts = current_app.config.get("MME_ACCEPTS")
-    mme_token = current_app.config.get("MME_TOKEN")
-
-    if not mme_base_url or not mme_accepts or not mme_token:
-        flash(
-            "An error occurred reading matchmaker connection parameters. Please check config file!",
-            "danger",
-        )
-        return redirect(request.referrer)
-
-    add_result = controllers.mme_add(
-        store=store,
-        user_obj=user_obj,
-        case_obj=case_obj,
-        add_gender=mme_save_options[0],
-        add_features=mme_save_options[1],
-        add_disorders=mme_save_options[2],
-        genes_only=genes_only,
-        mme_base_url=mme_base_url,
-        mme_accepts=mme_accepts,
-        mme_token=mme_token,
-    )
-
-    # flash MME responses (one for each patient posted)
-    n_succes_response = 0
-    n_inserted = 0
-    n_updated = 0
-    category = "warning"
-
-    for resp in add_result["server_responses"]:
-        message = resp.get("message")
-        if resp.get("status_code") == 200:
-            n_succes_response += 1
-        else:
-            flash(
-                "an error occurred while adding patient to matchmaker: {}".format(message),
-                "warning",
-            )
-        if message == "Patient was successfully updated.":
-            n_updated += 1
-        if message == "Patient was successfully inserted into database.":
-            n_inserted += 1
-
-    # if at least one patient was inserted or updated into matchmaker, save submission at the case level:
-    if n_inserted or n_updated:
-        category = "success"
-        store.case_mme_update(case_obj=case_obj, user_obj=user_obj, mme_subm_obj=add_result)
-    flash(
-        "Number of new patients in matchmaker:{0}, number of updated records:{1}, number of failed requests:{2}".format(
-            n_inserted, n_updated, len(add_result.get("server_responses")) - n_succes_response
-        ),
-        category,
-    )
-
+    # Call matchmaker_delete controller to add a patient to MatchMaker
+    controllers.matchmaker_add(request, institute_id, case_name)
     return redirect(request.referrer)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/mme_delete", methods=["POST"])
 def matchmaker_delete(institute_id, case_name):
     """Remove a case from MatchMaker"""
-
-    # check that only authorized users can delete patients from MME
-    user_obj = store.user(current_user.email)
-    if "mme_submitter" not in user_obj["roles"]:
-        flash("unauthorized request", "warning")
-        return redirect(request.referrer)
-
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    # Required params for sending a delete request to MME:
-    mme_base_url = current_app.config.get("MME_URL")
-    mme_token = current_app.config.get("MME_TOKEN")
-    if not mme_base_url or not mme_token:
-        flash(
-            "An error occurred reading matchmaker connection parameters. Please check config file!",
-            "danger",
-        )
-        return redirect(request.referrer)
-
-    delete_result = controllers.mme_delete(case_obj, mme_base_url, mme_token)
-
-    n_deleted = 0
-    category = "warning"
-
-    for resp in delete_result:
-        if resp["status_code"] == 200:
-            n_deleted += 1
-        else:
-            flash(resp["message"], category)
-    if n_deleted:
-        category = "success"
-        # update case by removing mme submission
-        # and create events for patients deletion from MME
-        user_obj = store.user(current_user.email)
-        store.case_mme_delete(case_obj=case_obj, user_obj=user_obj)
-    flash(
-        "Number of patients deleted from Matchmaker: {} out of {}".format(
-            n_deleted, len(delete_result)
-        ),
-        category,
-    )
+    # Call matchmaker_delete controller to delete a patient from MatchMaker
+    controllers.matchmaker_delete(request, institute_id, case_name)
     return redirect(request.referrer)
 
 
@@ -1078,7 +888,6 @@ def multiqc(institute_id, case_name):
 )
 def host_upd_regions_image(institute_id, case_name, individual, image):
     """Generate UPD REGIONS image file paths"""
-    LOG.debug("REGIONS")
     return host_image_aux(institute_id, case_name, individual, image, "upd_regions")
 
 
