@@ -80,7 +80,7 @@ def variants(institute_id, case_name):
             form.gene_panels.data = controllers.case_default_panels(case_obj)
 
     # populate filters dropdown
-    available_filters = store.filters(institute_id, category)
+    available_filters = list(store.filters(institute_id, category))
     form.filters.choices = [
         (filter.get("_id"), filter.get("display_name")) for filter in available_filters
     ]
@@ -129,6 +129,7 @@ def variants(institute_id, case_name):
         institute=institute_obj,
         case=case_obj,
         form=form,
+        filters=available_filters,
         manual_rank_options=MANUAL_RANK_OPTIONS,
         dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         cancer_tier_options=CANCER_TIER_OPTIONS,
@@ -171,7 +172,7 @@ def str_variants(institute_id, case_name):
         form.chrom.data = request.args.get("chrom", "")
 
     # populate filters dropdown
-    available_filters = store.filters(institute_id, category)
+    available_filters = list(store.filters(institute_id, category))
     form.filters.choices = [
         (filter.get("_id"), filter.get("display_name")) for filter in available_filters
     ]
@@ -211,6 +212,7 @@ def str_variants(institute_id, case_name):
         cytobands=cytobands,
         form=form,
         page=page,
+        filters=available_filters,
         expand_search=str(request.method == "POST"),
         result_size=result_size,
         total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
@@ -245,13 +247,22 @@ def sv_variants(institute_id, case_name):
 
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
+
     form = controllers.populate_sv_filters_form(store, institute_obj, case_obj, category, request)
 
+    # populate filters dropdown
+    available_filters = list(store.filters(institute_obj["_id"], category))
+    form.filters.choices = [
+        (filter.get("_id"), filter.get("display_name")) for filter in available_filters
+    ]
+
     # Populate chromosome select choices
     controllers.populate_chrom_choices(form, case_obj)
 
     cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
 
+    form = controllers.update_form_hgnc_symbols(store, case_obj, form)
+
     variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
 
     result_size = store.count_variants(case_obj["_id"], form.data, None, category)
@@ -270,6 +281,7 @@ def sv_variants(institute_id, case_name):
         dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         variant_type=variant_type,
         form=form,
+        filters=available_filters,
         cytobands=cytobands,
         severe_so_terms=SEVERE_SO_TERMS,
         manual_rank_options=MANUAL_RANK_OPTIONS,
@@ -335,7 +347,7 @@ def cancer_variants(institute_id, case_name):
     controllers.activate_case(store, institute_obj, case_obj, current_user)
 
     # populate filters dropdown
-    available_filters = store.filters(institute_id, category)
+    available_filters = list(store.filters(institute_id, category))
     form.filters.choices = [
         (filter.get("_id"), filter.get("display_name")) for filter in available_filters
     ]
@@ -344,22 +356,34 @@ def cancer_variants(institute_id, case_name):
     controllers.populate_chrom_choices(form, case_obj)
 
     form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
+    genome_build = "38" if "38" in str(case_obj.get("genome_build")) else "37"
+    cytobands = store.cytoband_by_chrom(genome_build)
 
-    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
-
-    variants_query = store.variants(case_obj["_id"], category="cancer", query=form.data)
+    variants_query = store.variants(
+        case_obj["_id"], category="cancer", query=form.data, build=genome_build
+    )
     result_size = store.count_variants(case_obj["_id"], form.data, None, category)
 
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
 
     data = controllers.cancer_variants(
-        store, institute_id, case_name, variants_query, result_size, form, page=page
+        store,
+        institute_id,
+        case_name,
+        variants_query,
+        result_size,
+        form,
+        page=page,
     )
-    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
+    expand_search = request.method == "POST" and request.form.get("expand_search") in [
+        "True",
+        "",
+    ]
     return dict(
         variant_type=variant_type,
         cytobands=cytobands,
+        filters=available_filters,
         dismiss_variant_options={
             **DISMISS_VARIANT_OPTIONS,
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
@@ -400,6 +424,12 @@ def cancer_sv_variants(institute_id, case_name):
     controllers.activate_case(store, institute_obj, case_obj, current_user)
     form = controllers.populate_sv_filters_form(store, institute_obj, case_obj, category, request)
 
+    # populate filters dropdown
+    available_filters = list(store.filters(institute_obj["_id"], category))
+    form.filters.choices = [
+        (filter.get("_id"), filter.get("display_name")) for filter in available_filters
+    ]
+
     # Populate chromosome select choices
     controllers.populate_chrom_choices(form, case_obj)
 
@@ -425,6 +455,7 @@ def cancer_sv_variants(institute_id, case_name):
         },
         variant_type=variant_type,
         form=form,
+        filters=available_filters,
         severe_so_terms=SEVERE_SO_TERMS,
         cancer_tier_options=CANCER_TIER_OPTIONS,
         manual_rank_options=MANUAL_RANK_OPTIONS,
