@@ -1,3 +1,5 @@
+from flask import get_template_attribute
+
 from scout.server.blueprints.variant.utils import (
     add_panel_specific_gene_info,
     clinsig_human,
@@ -12,6 +14,33 @@ from scout.server.blueprints.variant.utils import (
 )
 
 
+def test_modal_causative(app, case_obj, institute_obj, variant_obj):
+
+    # GIVEN an initialized app
+    with app.test_client() as client:
+
+        # WHILE collection a specific jinja macro
+        macro = get_template_attribute("variant/utils.html", "modal_causative")
+        # and passing to it the required parameters
+        # Including a case without HPO phenotype or diagnosis (OMIM terms) assigned
+        html = macro(case_obj, institute_obj, variant_obj)
+
+        # THEN the macro should contain the expected warning message
+        assert "Assign at least an OMIM diagnosis or a HPO phenotype term" in html
+
+        # WHEN the case contains one or more phenotype terms:
+        case_obj["phenotype_terms"] = {
+            "phenotype_id": "HPO:0002637",
+            "feature": "Cerebral ischemia",
+        }
+        # and/or OMIM diagnoses
+        case_obj["diagnosis_phenotypes"] = [616833]
+
+        # THEN the macro should allow to assign partial causatives
+        html = macro(case_obj, institute_obj, variant_obj)
+        assert "Assign at least an OMIM diagnosis or a HPO phenotype term" not in html
+
+
 def test_clinsig_human():
     ## GIVEN a variant with clinsig info
     var_obj = {
