@@ -3,22 +3,54 @@ import logging
 
 from bson.objectid import ObjectId
 from flask_wtf import FlaskForm
-from wtforms import SelectField
+from wtforms import SelectField, StringField
 
 from scout.constants import CHROMOSOMES_38, EXPORT_HEADER
 from scout.server.blueprints.variants.controllers import (
+    compounds_need_updating,
     gene_panel_choices,
     match_gene_txs_variant_txs,
     populate_chrom_choices,
     sv_variants,
+    update_form_hgnc_symbols,
     variant_export_lines,
     variants,
     variants_export_header,
 )
+from scout.server.extensions import store
 
 LOG = logging.getLogger(__name__)
 
 
+def test_compounds_need_updating():
+    """Test function that checks if variant compound objects need updating"""
+
+    # GIVEN a list of compounds for a variant missing the "not loaded key"
+    compounds = [{"variant": "aaa"}, {"variant": "bbb"}]
+    # THEN the function that checks if the compounds need updating should return True
+    assert compounds_need_updating(compounds, []) is True
+
+    # GIVEN a list of dismissed variants for a case
+    dismissed_variants = ["aaa", "ddd"]
+
+    # GIVEN a list of compounds with a compound missing dismissed status
+    # THEN the function that checks if the compounds need updating should return True
+    assert compounds_need_updating(compounds, dismissed_variants) is True
+
+    # GIVEN a list of compounds with a dismissed one that is not up-to-date (not in list of case dismissed variants)
+    compounds = [{"variant": "ccc", "is_dismissed": True}, {"variant": "bbb"}]
+    # THEN the function that checks if the compounds need updating should return True
+    assert compounds_need_updating(compounds, dismissed_variants) is True
+
+    # GIVEN an up-to-date list of compounds
+    compounds = [
+        {"variant": "aaa", "is_dismissed": True, "not_loaded": False},
+        {"variant": "bbb", "not_loaded": True},
+    ]
+    # THEN the function that checks if the compounds need updating should return False
+    assert compounds_need_updating(compounds, dismissed_variants) is False
+
+
 def test_populate_chrom_choices(app):
     """Test the function that populates the choices of the chromosome select in variants filters"""
 
@@ -333,3 +365,49 @@ def test_variant_csv_export(real_variant_database, case_obj):
     for export_line in export_lines:
         export_cols = export_line.split(",")
         assert len(export_cols) == len(export_header)
+
+
+def test_update_form_hgnc_symbols_valid_gene_symbol(app, case_obj):
+    """Test controller that populates HGNC symbols form filter in variants page. Provide valid gene symbol"""
+
+    # GIVEN a case analysed with a gene panel
+    test_panel = store.panel_collection.find_one()
+    case_obj["panels"] = [{"panel_id": test_panel["_id"]}]
+
+    # GIVEN a variants filter form
+    class TestForm(FlaskForm):
+        hgnc_symbols = StringField()
+        data = StringField()
+
+    form = TestForm()
+
+    # GIVEN a user trying to filter clinical variants using a valid gene symbol
+    form.hgnc_symbols.data = ["POT1"]
+    form.data = {"gene_panels": []}
+    updated_form = update_form_hgnc_symbols(store, case_obj, form)
+
+    # Form should be updated correctly
+    assert form.hgnc_symbols.data == ["POT1"]
+
+
+def test_update_form_hgnc_symbols_valid_gene_id(app, case_obj):
+    """Test controller that populates HGNC symbols form filter in variants page. Provide HGNC ID"""
+
+    # GIVEN a case analysed with a gene panel
+    test_panel = store.panel_collection.find_one()
+    case_obj["panels"] = [{"panel_id": test_panel["_id"]}]
+
+    # GIVEN a variants filter form
+    class TestForm(FlaskForm):
+        hgnc_symbols = StringField()
+        data = StringField()
+
+    form = TestForm()
+
+    # GIVEN a user trying to filter clinical variants using a valid gene ID
+    form.hgnc_symbols.data = ["17284"]
+    form.data = {"gene_panels": []}
+    updated_form = update_form_hgnc_symbols(store, case_obj, form)
+
+    # Form should be updated correctly
+    assert form.hgnc_symbols.data == ["POT1"]
