@@ -8,7 +8,9 @@ from flask_login import current_user
 from scout.server.extensions import store
 
 
-def test_variants_clinical_filter(app, institute_obj, case_obj):
+def test_variants_clinical_filter(app, institute_obj, case_obj, mocker, mock_redirect):
+
+    mocker.patch("scout.server.blueprints.variants.views.redirect", return_value=mock_redirect)
 
     # GIVEN a variant without clinVar annotations
     test_var = store.variant_collection.find_one(
@@ -42,13 +44,11 @@ def test_variants_clinical_filter(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
         # WHEN submitting form data to the variants page (POST method) with clinical filter
-        data = urlencode(
-            {
-                "clinical_filter": "Clinical filter",
-                "variant_type": "clinical",
-                "gene_panels": "panel1",
-            }
-        )  # clinical filter
+        data = {
+            "clinical_filter": "Clinical filter",
+            "variant_type": "clinical",
+            "gene_panels": "panel1",
+        }
 
         resp = client.post(
             url_for(
@@ -57,7 +57,6 @@ def test_variants_clinical_filter(app, institute_obj, case_obj):
                 case_name=case_obj["display_name"],
             ),
             data=data,
-            content_type="application/x-www-form-urlencoded",
         )
 
         # THEN it should return a page
@@ -88,14 +87,17 @@ def test_variants(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
-def test_bulk_reset_dismiss_variants(app, institute_obj, case_obj):
+def test_bulk_reset_dismiss_variants(app, institute_obj, case_obj, mocker, mock_redirect):
     """Test sending a GET request to reset all dismissed variants for a case"""
 
+    mocker.patch("scout.server.blueprints.variants.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app
     with app.test_client() as client:
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
 
+        # GIVEN a variant
         variant = store.variant_collection.find_one()
 
         # WHEN dismissing a variant using a POST request
@@ -125,7 +127,7 @@ def test_bulk_reset_dismiss_variants(app, institute_obj, case_obj):
                 "variants.reset_dismissed",
                 institute_id=institute_obj["internal_id"],
                 case_name=case_obj["display_name"],
-            ),
+            )
         )
         # THEN it should return redirect to variants page
         assert resp.status_code == 302
